.. include:: readme.rst

Contents
========
.. toctree::
   :maxdepth: 2

   tutorials
   faqs
   reference/index
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
